@@ -1,4 +1,5 @@
-
+from __future__ import unicode_literals
+import sys
 from ajax_select import get_lookup
 from django import forms
 from django.conf import settings
@@ -7,12 +8,23 @@ from django.core.urlresolvers import reverse
 from django.forms.util import flatatt
 from django.template.loader import render_to_string
 from django.template.defaultfilters import force_escape
+from django.utils.encoding import force_text
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext as _
-from django.utils import simplejson
+try:
+    import json
+except ImportError:
+    from django.utils import simplejson as json
 
 
-as_default_help = u'Enter text to search.'
+as_default_help = 'Enter text to search.'
+IS_PYTHON2 = sys.version_info.major == 2
+
+
+def _to_number(got):
+    if IS_PYTHON2:
+        return long(got)
+    return int(got)
 
 
 def _media(self):
@@ -41,7 +53,7 @@ class AutoCompleteSelectWidget(forms.widgets.TextInput):
 
     def __init__(self,
                  channel,
-                 help_text=u'',
+                 help_text='',
                  show_help_text=True,
                  plugin_options={},
                  *args,
@@ -73,7 +85,7 @@ class AutoCompleteSelectWidget(forms.widgets.TextInput):
         if self.show_help_text:
             help_text = self.help_text
         else:
-            help_text = u''
+            help_text = ''
 
         context = {
             'name': name,
@@ -93,7 +105,7 @@ class AutoCompleteSelectWidget(forms.widgets.TextInput):
 
         got = data.get(name, None)
         if got:
-            return long(got)
+            return _to_number(got)
         else:
             return None
 
@@ -129,7 +141,7 @@ class AutoCompleteSelectField(forms.fields.CharField):
                 # someone else might have deleted it while you were editing
                 # or your channel is faulty
                 # out of the scope of this field to do anything more than tell you it doesn't exist
-                raise forms.ValidationError(u"%s cannot find object: %s" % (lookup, value))
+                raise forms.ValidationError("%s cannot find object: %s" % (lookup, value))
             return objs[0]
         else:
             if self.required:
@@ -193,14 +205,14 @@ class AutoCompleteSelectMultipleWidget(forms.widgets.SelectMultiple):
         if self.show_help_text:
             help_text = self.help_text
         else:
-            help_text = u''
+            help_text = ''
 
         context = {
             'name': name,
             'html_id': self.html_id,
             'current': value,
             'current_ids': current_ids,
-            'current_reprs': mark_safe(simplejson.dumps(initial)),
+            'current_reprs': mark_safe(json.dumps(initial)),
             'help_text': help_text,
             'extra_attrs': mark_safe(flatatt(final_attrs)),
             'func_slug': self.html_id.replace("-", ""),
@@ -211,8 +223,8 @@ class AutoCompleteSelectMultipleWidget(forms.widgets.SelectMultiple):
         return mark_safe(render_to_string(('autocompleteselectmultiple_%s.html' % self.channel, 'autocompleteselectmultiple.html'), context))
 
     def value_from_datadict(self, data, files, name):
-        # eg. u'members': [u'|229|4688|190|']
-        return [long(val) for val in data.get(name, '').split('|') if val]
+        # eg. 'members': ['|229|4688|190|']
+        return [_to_number(val) for val in data.get(name, '').split('|') if val]
 
     def id_for_label(self, id_):
         return '%s_text' % id_
@@ -232,26 +244,26 @@ class AutoCompleteSelectMultipleField(forms.fields.CharField):
 
         if not (help_text is None):
             # '' will cause translation to fail
-            # should be u''
+            # should be ''
             if type(help_text) == str:
-                help_text = unicode(help_text)
+                help_text = force_text(help_text)
             # django admin appends "Hold down "Control",..." to the help text
             # regardless of which widget is used. so even when you specify an explicit help text it appends this other default text onto the end.
             # This monkey patches the help text to remove that
-            if help_text != u'':
-                if type(help_text) != unicode:
+            if help_text != '':
+                if not self._is_string(help_text):
                     # ideally this could check request.LANGUAGE_CODE
                     translated = help_text.translate(settings.LANGUAGE_CODE)
                 else:
                     translated = help_text
-                django_default_help = _(u'Hold down "Control", or "Command" on a Mac, to select more than one.').translate(settings.LANGUAGE_CODE)
+                django_default_help = _('Hold down "Control", or "Command" on a Mac, to select more than one.').translate(settings.LANGUAGE_CODE)
                 if django_default_help in translated:
                     cleaned_help = translated.replace(django_default_help, '').strip()
                     # probably will not show up in translations
                     if cleaned_help:
                         help_text = cleaned_help
                     else:
-                        help_text = u""
+                        help_text = ""
                         show_help_text = False
         else:
             help_text = _(as_default_help)
@@ -272,6 +284,12 @@ class AutoCompleteSelectMultipleField(forms.fields.CharField):
 
         super(AutoCompleteSelectMultipleField, self).__init__(*args, **kwargs)
 
+    @staticmethod
+    def _is_string(help_text):
+        if IS_PYTHON2:
+            return type(help_text) == unicode
+        return type(help_text) == str
+
     def clean(self, value):
         if not value and self.required:
             raise forms.ValidationError(self.error_messages['required'])
@@ -316,7 +334,7 @@ class AutoCompleteWidget(forms.TextInput):
         if self.show_help_text:
             help_text = self.help_text
         else:
-            help_text = u''
+            help_text = ''
 
         context = {
             'current_repr': initial,
@@ -378,7 +396,7 @@ def _check_can_add(self, user, model):
 
 def autoselect_fields_check_can_add(form, model, user):
     """ check the form's fields for any autoselect fields and enable their widgets with + sign add links if permissions allow"""
-    for name, form_field in form.declared_fields.iteritems():
+    for name, form_field in form.declared_fields.items():
         if isinstance(form_field, (AutoCompleteSelectMultipleField, AutoCompleteSelectField)):
             db_field = model._meta.get_field_by_name(name)[0]
             form_field.check_can_add(user, db_field.rel.to)
@@ -403,8 +421,8 @@ def plugin_options(channel, channel_name, widget_plugin_options, initial):
         po['html'] = True
 
     return {
-        'plugin_options': mark_safe(simplejson.dumps(po)),
-        'data_plugin_options': force_escape(simplejson.dumps(po)),
+        'plugin_options': mark_safe(json.dumps(po)),
+        'data_plugin_options': force_escape(json.dumps(po)),
         # continue to support any custom templates that still expect these
         'lookup_url': po['source'],
         'min_length': po['min_length']
