@@ -3,7 +3,11 @@ from ajax_select import get_lookup
 from django.contrib.admin import site
 from django.db import models
 from django.http import HttpResponse
-from django.utils import simplejson
+try:
+    import json
+except ImportError:
+    from django.utils import simplejson as json
+from django.utils.encoding import force_text
 
 
 def ajax_lookup(request, channel):
@@ -31,9 +35,9 @@ def ajax_lookup(request, channel):
     else:
         instances = []
 
-    results = simplejson.dumps([
+    results = json.dumps([
         {
-            'pk': unicode(getattr(item, 'pk', None)),
+            'pk': force_text(getattr(item, 'pk', None)),
             'value': lookup.get_result(item),
             'match': lookup.format_match(item),
             'repr': lookup.format_item_display(item)
